@@ -1,5 +1,5 @@
 import imp, os, sys
-if "DEBUG" not in globals(): DEBUG = 0 # set to 0 to suppress printing debug info
+if "DEBUG" not in globals(): DEBUG = 0 # True enables printing debug info
 
 ######## import hook
 class importer(object):
@@ -49,5 +49,6 @@ class importer(object):
       return m
     except:
       if new: del sys.modules[mname] # if new module fails loading, del from sys.modules
+      print( "\nFAILED py3to2 load_module(mname = %s, fpath = %s, desc = %s)\n" % (mname, fpath, desc) ) # notify user exception originated from failed py3to2 import
       raise
 importer()
